@@ -1,11 +1,9 @@
 package Apache::AuthCookie::Util;
-{
-  $Apache::AuthCookie::Util::VERSION = '3.19_01';
-}
-
-# ABSTRACT: Internal Utility Functions for AuthCookie
 
 use strict;
+use vars '$VERSION';
+
+$VERSION = do { my @r = (q$Revision: 222 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
 
 # -- expires() shamelessly taken from CGI::Util
 sub expires {
@@ -75,50 +73,4 @@ sub escape_destination {
     return $text;
 }
 
-# return true if the given user agent understands a HTTP_FORBIDDEN response
-# with custom content. Some agents (e.g.: Symbian OS browser), use their own
-# HTML and completely ignore the HTTP content.
-sub understands_forbidden_response {
-    my $ua = shift;
-
-    return 0 if $ua =~ qr{\AMozilla/5\.0 \(SymbianOS/};
-
-    return 1;
-}
-
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Apache::AuthCookie::Util - Internal Utility Functions for AuthCookie
-
-=head1 VERSION
-
-version 3.19_01
-
-=head1 SOURCE
-
-The development version is on github at L<http://github.com/mschout/apache-authcookie>
-and may be cloned from L<git://github.com/mschout/apache-authcookie.git>
-
-=head1 BUGS
-
-Please report any bugs or feature requests to bug-apache-authcookie@rt.cpan.org or through the web interface at:
- http://rt.cpan.org/Public/Dist/Display.html?Name=Apache-AuthCookie
-
-=head1 AUTHOR
-
-Michael Schout <mschout@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2000 by Ken Williams.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
