@@ -17,8 +17,8 @@ use APR::Table;
 use Apache2::Const qw(:common M_GET HTTP_FORBIDDEN HTTP_MOVED_TEMPORARILY);
 use vars qw($VERSION);
 
-# $Id: AuthCookie.pm,v 1.18 2006/05/04 05:08:25 mschout Exp $
-$VERSION = '3.09';
+# $Id: AuthCookie.pm 222 2008-02-29 18:40:40Z mschout $
+$VERSION = '3.11';
 
 sub recognize_user {
     my ($self, $r) = @_;
@@ -202,11 +202,18 @@ sub login {
         $r->server->log_error("redirect to $args{destination}");
     }
 
-    $r->headers_out->set("Location" => $args{'destination'});
+    $r->headers_out->set(
+        "Location" => $self->untaint_destination($args{'destination'}));
 
     return HTTP_MOVED_TEMPORARILY;
 }
 
+sub untaint_destination {
+    my ($self, $dest) = @_;
+
+    return Apache::AuthCookie::Util::escape_destination($dest);
+}
+
 sub logout {
     my ($self,$r) = @_;
 
@@ -225,8 +232,10 @@ sub authenticate {
     $r->server->log_error("auth_type " . $auth_type) if ($debug >= 3);
 
     unless ($r->is_initial_req) {
-        # we are in a subrequest.  Just copy user from previous request.
-        $r->user( $r->prev->user );
+        if (defined $r->prev) {
+            # we are in a subrequest.  Just copy user from previous request.
+            $r->user( $r->prev->user );
+        }
         return OK;
     }
 
@@ -903,6 +912,15 @@ handy inside a method that implements a C<require> directive check
 (like the C<species> method discussed above) if you put any extra
 information like clearances or whatever into the session key.
 
+=item * untaint_destination($self, $uri)
+
+This method returns a modified version of the destination parameter
+before embedding it into the response header. Per default it escapes
+CR, LF and TAB characters of the uri to avoid certain types of
+security attacks. You can override it to more limit the allowed
+destinations, e.g., only allow relative uris, only special hosts or
+only limited set of characters.
+
 =back
 
 =head1 EXAMPLE
@@ -1037,7 +1055,7 @@ implement anything, though.
 
 =head1 CVS REVISION
 
-$Id: AuthCookie.pm,v 1.18 2006/05/04 05:08:25 mschout Exp $
+$Id: AuthCookie.pm 222 2008-02-29 18:40:40Z mschout $
 
 =head1 AUTHOR
 
